==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/events/MapAdminEventEntityFieldDelegate.java <==
package org.keycloak.models.map.events;
public class MapAdminEventEntityFieldDelegate extends org.keycloak.models.map.events.MapAdminEventEntity.AbstractAdminEventEntity implements org.keycloak.models.map.events.MapAdminEventEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.events.MapAdminEventEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.events.MapAdminEventEntity> entityFieldDelegate;
    public MapAdminEventEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.events.MapAdminEventEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.events.MapAdminEventEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getExpiration() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.EXPIRATION);
    }
    @SuppressWarnings("unchecked") @Override public void setExpiration(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.EXPIRATION, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getTimestamp() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.TIMESTAMP);
    }
    @SuppressWarnings("unchecked") @Override public void setTimestamp(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.TIMESTAMP, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public org.keycloak.events.admin.OperationType getOperationType() {
        return (org.keycloak.events.admin.OperationType) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.OPERATION_TYPE);
    }
    @SuppressWarnings("unchecked") @Override public void setOperationType(org.keycloak.events.admin.OperationType p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.OPERATION_TYPE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getResourcePath() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.RESOURCE_PATH);
    }
    @SuppressWarnings("unchecked") @Override public void setResourcePath(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.RESOURCE_PATH, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRepresentation() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.REPRESENTATION);
    }
    @SuppressWarnings("unchecked") @Override public void setRepresentation(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.REPRESENTATION, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getError() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.ERROR);
    }
    @SuppressWarnings("unchecked") @Override public void setError(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.ERROR, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getResourceType() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.RESOURCE_TYPE);
    }
    @SuppressWarnings("unchecked") @Override public void setResourceType(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.RESOURCE_TYPE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAuthRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAuthClientId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_CLIENT_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthClientId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_CLIENT_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAuthUserId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_USER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthUserId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_USER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAuthIpAddress() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_IP_ADDRESS);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthIpAddress(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_IP_ADDRESS, p0);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/events/MapAdminEventEntityFieldDelegate.java <==
package org.keycloak.models.map.events;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapAdminEventEntityFieldDelegate extends org.keycloak.models.map.events.MapAdminEventEntity.AbstractAdminEventEntity implements org.keycloak.models.map.events.MapAdminEventEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.events.MapAdminEventEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.events.MapAdminEventEntity> entityFieldDelegate;
    public MapAdminEventEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.events.MapAdminEventEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.events.MapAdminEventEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getExpiration() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.EXPIRATION);
    }
    @SuppressWarnings("unchecked") @Override public void setExpiration(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.EXPIRATION, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getTimestamp() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.TIMESTAMP);
    }
    @SuppressWarnings("unchecked") @Override public void setTimestamp(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.TIMESTAMP, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public org.keycloak.events.admin.OperationType getOperationType() {
        return (org.keycloak.events.admin.OperationType) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.OPERATION_TYPE);
    }
    @SuppressWarnings("unchecked") @Override public void setOperationType(org.keycloak.events.admin.OperationType p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.OPERATION_TYPE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getResourcePath() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.RESOURCE_PATH);
    }
    @SuppressWarnings("unchecked") @Override public void setResourcePath(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.RESOURCE_PATH, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRepresentation() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.REPRESENTATION);
    }
    @SuppressWarnings("unchecked") @Override public void setRepresentation(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.REPRESENTATION, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getError() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.ERROR);
    }
    @SuppressWarnings("unchecked") @Override public void setError(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.ERROR, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getResourceType() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.RESOURCE_TYPE);
    }
    @SuppressWarnings("unchecked") @Override public void setResourceType(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.RESOURCE_TYPE, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAuthRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAuthClientId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_CLIENT_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthClientId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_CLIENT_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAuthUserId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_USER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthUserId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_USER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAuthIpAddress() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_IP_ADDRESS);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthIpAddress(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.events.MapAdminEventEntityFields.AUTH_IP_ADDRESS, p0);
    }
}
